# 
# This file is part of Curses-Toolkit
# 
# This software is copyright (c) 2008 by Damien "dams" Krotkine.
# 
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
# 
use warnings;
use strict;

package Curses::Toolkit::Widget::Window::Dialog;
our $VERSION = '0.100630';



# ABSTRACT: a dialog window

use parent qw(Curses::Toolkit::Widget::Window);

1;



=pod

=head1 NAME

Curses::Toolkit::Widget::Window::Dialog - a dialog window

=head1 VERSION

version 0.100630

=head1 SYNOPSIS

    # FIXME: not yet implemented

=head1 DESCRIPTION

This widget is a dialog window.



=head1 AUTHOR

  Damien "dams" Krotkine

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2008 by Damien "dams" Krotkine.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut 



__END__